@@ -79,9 +79,10 @@ abstract class Horde_Alarm_Storage_Base extends Horde_Test_Case
      */
     public function testListAlarms()
     {
-        self::$date->min--;
+        $date = clone self::$date;
+        $date->min--;
         self::$alarm->set(array('id' => 'publicalarm',
-                                'start' => self::$date,
+                                'start' => $date,
                                 'end' => self::$end,
                                 'methods' => array(),
                                 'params' => array(),
@@ -138,9 +139,11 @@ abstract class Horde_Alarm_Storage_Base extends Horde_Test_Case
      */
     public function testAlarmWithoutEnd()
     {
+        $start = clone self::$date;
+        $start->min--;
         self::$alarm->set(array('id' => 'noend',
                                 'user' => 'john',
-                                'start' => self::$date,
+                                'start' => $start,
                                 'methods' => array('notify'),
                                 'params' => array(),
                                 'title' => 'This is an alarm without end.'));
